API Reference
=============

Client
------

.. autoclass:: bunnydns.BunnyDNS
   :members:
   :undoc-members:

Models
------

.. autoclass:: bunnydns.DnsZone
   :members:

.. autoclass:: bunnydns.DnsZoneList
   :members:

.. autoclass:: bunnydns.DnsRecord
   :members:

.. autoclass:: bunnydns.DnsRecordInput
   :members:

.. autoclass:: bunnydns.DnsSecDsRecord
   :members:

.. autoclass:: bunnydns.DnsZoneImportResult
   :members:

.. autoclass:: bunnydns.IPGeoLocationInfo
   :members:

.. autoclass:: bunnydns.GeolocationInfo
   :members:

.. autoclass:: bunnydns.EnvironmentalVariable
   :members:

Enums
-----

.. autoclass:: bunnydns.RecordType
   :members:
   :undoc-members:

.. autoclass:: bunnydns.MonitorStatus
   :members:
   :undoc-members:

.. autoclass:: bunnydns.MonitorType
   :members:
   :undoc-members:

.. autoclass:: bunnydns.SmartRoutingType
   :members:
   :undoc-members:

.. autoclass:: bunnydns.AccelerationStatus
   :members:
   :undoc-members:

.. autoclass:: bunnydns.LogAnonymizationType
   :members:
   :undoc-members:

.. autoclass:: bunnydns.CertificateKeyType
   :members:
   :undoc-members:

Exceptions
----------

.. autoexception:: bunnydns.BunnyDNSError
.. autoexception:: bunnydns.BunnyDNSAuthenticationError
.. autoexception:: bunnydns.BunnyDNSNotFoundError
.. autoexception:: bunnydns.BunnyDNSAPIError
